@@ -30,11 +30,7 @@ public:
     ~UsbDeviceMonitor();
     
     // Implements QAbstractNativeEventFilter interface for processing WM_DEVICECHANGE messages (Windows)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    bool nativeEventFilter(const QByteArray &theEventType, void *theMessage, long * theResult) override;
-#else
     bool nativeEventFilter(const QByteArray &theEventType, void *theMessage, qintptr *theResult) override;
-#endif
 
 protected:
     // Closes handles and frees resources
